import axios          from 'axios';
import GitlabPipeline from '../types/Gitlab/GitlabPipeline';
import GitlabRoute    from '../types/Gitlab/GitlabRoute';
import SharedConfig   from '../config/SharedConfig';
import GitlabToken    from '../types/Gitlab/GitlabToken';


class GitlabManager {
    private getApiUrl(route: GitlabRoute): string {
        return `${ SharedConfig.gitlab.apiURL }${ route }`;
    }

    async getTokens(codeOrRefresh: string, isRefresh: boolean = false, clientSecret: string = ''): Promise<GitlabToken> {
        const response = await axios.post<GitlabToken>(SharedConfig.login.gitlab.url.token, {
            client_id    : SharedConfig.login.gitlab.client.id,
            client_secret: clientSecret,
            grant_type   : isRefresh ? 'refresh_token' : 'authorization_code',
            refresh_token: codeOrRefresh,
            code         : codeOrRefresh,
            redirect_uri : SharedConfig.login.gitlab.url.redirect
        });

        return response.data;
    }

    async getRepositoryPipelines(repoId: number, branch: string = 'main'): Promise<Array<GitlabPipeline>> {
        const response = await axios.get<Array<GitlabPipeline>>(this.getApiUrl(GitlabRoute.REPOSITORY_PIPELINES).replace('{{id}}', String(repoId)), {
            params: {
                ref: branch
            }
        });

        return response.data;
    }
}


export default new GitlabManager();
