import axios        from 'axios';
import https        from 'https';
import SharedConfig from '../config/SharedConfig';


class SharedSonarManager {

    // Use custom instance to allow self-signed certificates
    private instance = axios.create({
        httpsAgent: new https.Agent({
            rejectUnauthorized: false
        })
    });
    async isSonarSupported(): Promise<boolean> {
        if (!SharedConfig.sonar.enabled) {
            return false;
        }
        try {
            const sonar = await this.instance.get(SharedConfig.sonar.url);
            return sonar.status == 200;
        } catch ( error ) {
            return false;
        }
    }

    /**
     * Map a language name to the equivalent language ID in Sonar
     * Most language have the same name, so by default the same name is returned, even for languages that doesn't exist in sonar.
     * @param language
     */
    mapLanguage(language: string): string {
        switch (language) {
            case "csharp":
                return "cs";
            case "python":
                return "py";
            default:
                return language;
        }
    }
}

export default new SharedSonarManager();